.. _contributor-guide-index:

.. TODO: Include text from CONTRIBUTING.rst similar to how the README and sphinx Home page are aligned

.. toctree::
   :maxdepth: 1
   :caption: Contributor Guide
   :hidden:

   setup
   how_to_contribute
   testing
   documentation
   package_builds
   release_process


Contributing
============

Welcome to the Contributor Guide! In this section you will find all the information you need to contribute to ARTKIT.

Ways to Contribute
------------------

There are many ways to contribute, including:

- Create issues for bugs or feature requests
- Address an `open issue <https://github.com/BCG-X-Official/artkit/issues>`_
- Add new model connectors
- Add or improve unit tests
- Create tutorials
- Improve documentation

We especially encourage contributions that integrate additional model providers and enhance our documentation.

For major contributions, please reach out to the ARTKIT team in advance (ARTKIT@bcg.com).